@@ -1,5 +1,5 @@
 var interfacecom_1_1sun_1_1star_1_1frame_1_1XUIControllerFactory =
 [
-    [ "XMultiComponentFactory", "interfacecom_1_1sun_1_1star_1_1frame_1_1XUIControllerFactory.html#a3dfecfa6f0d7bff5cea55f4dbca76af1", null ],
+    [ "com::sun::star::lang::XMultiComponentFactory", "interfacecom_1_1sun_1_1star_1_1frame_1_1XUIControllerFactory.html#a3dfecfa6f0d7bff5cea55f4dbca76af1", null ],
     [ "XUIControllerRegistration", "interfacecom_1_1sun_1_1star_1_1frame_1_1XUIControllerFactory.html#a3ac0ce0d4be5f34469a6a713362c795f", null ]
 ];
\ No newline at end of file
