@@ -1,7 +1,7 @@
 var servicecom_1_1sun_1_1star_1_1chart_1_1ChartTwoAxisXSupplier =
 [
-    [ "ChartAxisXSupplier", "servicecom_1_1sun_1_1star_1_1chart_1_1ChartTwoAxisXSupplier.html#aab58cbe472071c572cb6cf1fb984bb7e", null ],
-    [ "XTwoAxisXSupplier", "servicecom_1_1sun_1_1star_1_1chart_1_1ChartTwoAxisXSupplier.html#a1e1d71a71c346c97e8782aa2cd70943d", null ],
+    [ "com::sun::star::chart::ChartAxisXSupplier", "servicecom_1_1sun_1_1star_1_1chart_1_1ChartTwoAxisXSupplier.html#aab58cbe472071c572cb6cf1fb984bb7e", null ],
+    [ "com::sun::star::chart::XTwoAxisXSupplier", "servicecom_1_1sun_1_1star_1_1chart_1_1ChartTwoAxisXSupplier.html#a1e1d71a71c346c97e8782aa2cd70943d", null ],
     [ "HasSecondaryXAxis", "servicecom_1_1sun_1_1star_1_1chart_1_1ChartTwoAxisXSupplier.html#a5c308ac270e64d536590033d5b5d7ea0", null ],
     [ "HasSecondaryXAxisDescription", "servicecom_1_1sun_1_1star_1_1chart_1_1ChartTwoAxisXSupplier.html#a6aa4b6dc40ca2212bab536e12736195f", null ],
     [ "HasSecondaryXAxisTitle", "servicecom_1_1sun_1_1star_1_1chart_1_1ChartTwoAxisXSupplier.html#a4fbc0451d19cfdaa33bce59fff2815d6", null ]
